Description Usage Format See Also
A QFeatures object that has been generated to run exercise 2. It was generated
from the v02-scp.Rmd vignette that replicates the SCoPE2 data
processing workflow for batch LCB3 up to the aggregation of PSMs
to peptides. This dataset can be used to demonstrate the use of
aggregateFeaturesOverAssays.
lcb3_2: contains 24 assays, each assay contains PSM data for one of
the 24 MS runs.
1 | data("lcb3_2")
|
An object of class QFeatures of length 24.
Other exercise datasets are available: lcb3_1, lcb3_3, lcb3_4, lcb3_5.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.