lcb3_3: Data for exercise 3

Description Usage Format See Also

Description

A QFeatures object that has been generated to run exercise 3. It was generated from the v02-scp.Rmd vignette that replicates the SCoPE2 data processing workflow for batch LCB3 up to the QC and filtering of single-cells based on the CV. This dataset can be used to demonstrate the use of subsetByColData.

lcb3_3 contains 49 assays:

Usage

1
data("lcb3_3")

Format

An object of class QFeatures of length 49.

See Also

Other exercise datasets are available: lcb3_1, lcb3_2, lcb3_4, lcb3_5.


lgatto/QFeaturesScpWorkshop2021 documentation built on Dec. 21, 2021, 10:44 a.m.