lcb3_4: Data for exercise 4

Description Usage Format See Also

Description

A QFeatures object that has been generated to run exercise 4. It was generated from the v02-scp.Rmd vignette that replicates the SCoPE2 data processing workflow for batch LCB3 up to batch correction. This dataset can be used to demonstrate how to add SingleCellExperiment objects as new assay in a QFeatures object and create links with a parent assay.

lcb3_4 contains 55 assays:

sce corresponds to Assay 55 after batch correction using ComBat.

Usage

1
data("lcb3_4")

Format

An object of class QFeatures of length 55.

See Also

Other exercise datasets are available: lcb3_1, lcb3_2, lcb3_3, lcb3_5.


lgatto/QFeaturesScpWorkshop2021 documentation built on Dec. 21, 2021, 10:44 a.m.