lcb3_5: Data for exercise 5

Description Usage Format See Also

Description

A QFeatures object that has been generated to run exercise 5. It was generated from the v02-scp.Rmd vignette that replicates the SCoPE2 data processing workflow for batch LCB3 up to data visualization. This dataset can be used to demonstrate the use of longFormat.

lcb3_5 contains 58 assays:

Usage

1
data("lcb3_5")

Format

An object of class QFeatures of length 58.

See Also

Other exercise datasets are available: lcb3_1, lcb3_2, lcb3_3, lcb3_4.


lgatto/QFeaturesScpWorkshop2021 documentation built on Dec. 21, 2021, 10:44 a.m.