Description Usage Format See Also
A QFeatures object that has been generated to run
exercise 3. It was generated from the v02-scp.Rmd vignette that
replicates the SCoPE2 data processing workflow for batch LCB3 up to
the QC and filtering of single-cells based on the CV. This dataset
can be used to demonstrate the use of subsetByColData.
lcb3_3 contains 49 assays:
Assay 1-24: PSM data for 24 MS runs
Assay 25-48: aggregated peptide data for 24 MS runs
Assay 49: joined peptide data containing the sample of all 24 MS runs
1 | data("lcb3_3")
|
An object of class QFeatures of length 49.
Other exercise datasets are available: lcb3_1, lcb3_2, lcb3_4, lcb3_5.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.