Description Usage Format See Also
A QFeatures object that has been generated to run
exercise 5. It was generated from the v02-scp.Rmd vignette that
replicates the SCoPE2 data processing workflow for batch LCB3 up to
data visualization. This dataset can be used to demonstrate the use
of longFormat.
lcb3_5 contains 58 assays:
Assay 1-24: PSM data for 24 MS runs
Assay 25-48: aggregated peptide data for 24 MS runs
Assay 49: joined peptide data containing the sample of all 24 MS runs
Assay 50: peptide data after a first normalization
Assay 51: peptide data after a second normalization
Assay 52: peptide data after log-transformation
Assay 53: aggregated protein data
Assay 54: protein data after a first normalization
Assay 55: protein data after a second normalization and imputation of missing data
Assay 56: batch corrected protein data
Assay 57: batch corrected protein data after a first normalization
Assay 58: batch corrected protein data after a second normalization
1 | data("lcb3_5")
|
An object of class QFeatures of length 58.
Other exercise datasets are available: lcb3_1, lcb3_2, lcb3_3, lcb3_4.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.